Generated file from shared/sp_shared.proto
Structs
- WasmModule is used to ensure we only send the wasm module once per request instead of duplicated in every pipeline where it is used. This prevents over-sized payloads on SDK startup
Enums
- KVAction is a shared type that is used for protos.KVCommand and protos.KVStep. Note that only a subset of actions are used for protos.KVCommand (CREATE, UPDATE, DELETE, DELETE_ALL) while protos.KVStep uses most of them.
Functions
FileDescriptorobject which allows dynamic access to files