Struct protos::sp_steps_kv::KVStepResponse
source · pub struct KVStepResponse {
pub status: EnumOrUnknown<KVStatus>,
pub message: String,
pub value: Option<Vec<u8>>,
pub special_fields: SpecialFields,
}Expand description
Returned by SDK host func and interpreted by KV WASM.
Fields
status: EnumOrUnknown<KVStatus>Status of the action; interpreted by KV WASM to so it can generate a protos.WASMResponse
message: StringMessage containing info, debug or error details; included in protos.WASMResponse
value: Option<Vec<u8>>Optional because the only action that uses field is KV_ACTION_GET
DS: Not sure how we’ll use KV_ACTION_GET in steps yet but this is probably a good place to start. 09.06.2023.
special_fields: SpecialFieldsImplementations
sourceimpl KVStepResponse
impl KVStepResponse
pub fn new() -> KVStepResponse